@@ -21,9 +21,7 @@
 #include <KItinerary/Place>
 #include <KItinerary/Reservation>
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
 #include <QAbstractItemModelTester>
-#endif
 #include <QDirIterator>
 #include <QUrl>
 #include <QtTest/qtest.h>
@@ -117,9 +115,7 @@ private Q_SLOTS:
 
         resMgr.setPkPassManager(&mgr);
         TimelineModel model;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
         QAbstractItemModelTester tester(&model);
-#endif
         model.setReservationManager(&resMgr);
 
         QSignalSpy insertSpy(&model, &TimelineModel::rowsInserted);
@@ -158,9 +154,7 @@ private Q_SLOTS:
         clearReservations(&resMgr);
 
         TimelineModel model;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
         QAbstractItemModelTester tester(&model);
-#endif
         model.setHomeCountryIsoCode(QStringLiteral("DE"));
         model.setReservationManager(&resMgr);
 
@@ -213,9 +207,7 @@ private Q_SLOTS:
         clearReservations(&resMgr);
 
         TimelineModel model;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
         QAbstractItemModelTester tester(&model);
-#endif
         model.setHomeCountryIsoCode(QStringLiteral("DE"));
         model.setReservationManager(&resMgr);
 
@@ -265,9 +257,7 @@ private Q_SLOTS:
         weatherMgr.setTestModeEnabled(true);
 
         TimelineModel model;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
         QAbstractItemModelTester tester(&model);
-#endif
         model.setReservationManager(&resMgr);
         model.setWeatherForecastManager(&weatherMgr);
         QCOMPARE(model.rowCount(), 1); // no weather data, as we don't know where we are
@@ -339,7 +329,7 @@ private Q_SLOTS:
         // check we get update signals for all weather elements
         QSignalSpy spy(&model, &TimelineModel::dataChanged);
         QVERIFY(spy.isValid());
-        emit weatherMgr.forecastUpdated();
+        Q_EMIT weatherMgr.forecastUpdated();
         QCOMPARE(spy.size(), 10);
 
         fc = model.index(3, 0).data(TimelineModel::WeatherForecastRole).value<WeatherForecast>();
@@ -410,9 +400,7 @@ private Q_SLOTS:
         ReservationManager resMgr;
         clearReservations(&resMgr);
         TimelineModel model;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
         QAbstractItemModelTester tester(&model);
-#endif
         model.setReservationManager(&resMgr);
         QCOMPARE(model.rowCount(), 1); // 1x TodayMarker
 
@@ -488,9 +476,7 @@ private Q_SLOTS:
         weatherMgr.setTestModeEnabled(true);
 
         TimelineModel model;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
         QAbstractItemModelTester tester(&model);
-#endif
         model.setHomeCountryIsoCode(QStringLiteral("DE"));
         model.setCurrentDateTime(QDateTime({2196, 10, 14}, {12, 34}));
         model.setReservationManager(&resMgr);
@@ -561,9 +547,7 @@ private Q_SLOTS:
         transferMgr.setFavoriteLocationModel(&favLocModel);
 
         TimelineModel model;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
         QAbstractItemModelTester tester(&model);
-#endif
         model.setHomeCountryIsoCode(QStringLiteral("DE"));
         model.setCurrentDateTime(QDateTime({1996, 10, 14}, {12, 34}));
         model.setReservationManager(&resMgr);
