@@ -7,11 +7,16 @@
 #include "applicationcontroller.h"
 #include "documentmanager.h"
 #include "favoritelocationmodel.h"
+#include "gpxexport.h"
+#include "healthcertificatemanager.h"
 #include "importexport.h"
+#include "livedatamanager.h"
 #include "logging.h"
 #include "pkpassmanager.h"
 #include "reservationmanager.h"
 #include "transfermanager.h"
+#include "tripgroup.h"
+#include "tripgroupmanager.h"
 #include <itinerary_version_detailed.h>
 
 #include <KItinerary/CreativeWork>
@@ -64,14 +69,6 @@ using namespace KItinerary;
 
 #ifdef Q_OS_ANDROID
 
-static void importReservation(JNIEnv *env, jobject that, jstring data)
-{
-    Q_UNUSED(that)
-    const char *str = env->GetStringUTFChars(data, nullptr);
-    ApplicationController::instance()->importData(str);
-    env->ReleaseStringUTFChars(data, str);
-}
-
 static void importDavDroidJson(JNIEnv *env, jobject that, jstring data)
 {
     Q_UNUSED(that)
@@ -99,7 +96,6 @@ static void importFromIntent(JNIEnv *env, jobject that, jobject data)
 }
 
 static const JNINativeMethod methods[] = {
-    {"importReservation", "(Ljava/lang/String;)V", (void*)importReservation},
     {"importFromIntent", "(Landroid/content/Intent;)V", (void*)importFromIntent},
     {"importDavDroidJson", "(Ljava/lang/String;)V", (void*)importDavDroidJson}
 };
@@ -176,6 +172,16 @@ void ApplicationController::setLiveDataManager(LiveDataManager *liveDataMgr)
     m_liveDataMgr = liveDataMgr;
 }
 
+void ApplicationController::setTripGroupManager(TripGroupManager *tripGroupMgr)
+{
+    m_tripGroupMgr = tripGroupMgr;
+}
+
+void ApplicationController::setHealthCertificateManager(HealthCertificateManager *healthCertMgr)
+{
+    m_healthCertMgr = healthCertMgr;
+}
+
 #ifdef Q_OS_ANDROID
 void ApplicationController::importFromIntent(const KAndroidExtras::Intent &intent)
 {
@@ -244,17 +250,22 @@ void ApplicationController::importFromIntent(const KAndroidExtras::Intent &inten
 
 void ApplicationController::importFromClipboard()
 {
-    if (QGuiApplication::clipboard()->mimeData()->hasUrls()) {
-        const auto urls = QGuiApplication::clipboard()->mimeData()->urls();
-        for (const auto &url : urls)
+    const auto md = QGuiApplication::clipboard()->mimeData();
+    if (md->hasUrls()) {
+        const auto urls = md->urls();
+        for (const auto &url : urls) {
             importFromUrl(url);
-        return;
+        }
     }
 
-    if (QGuiApplication::clipboard()->mimeData()->hasText()) {
-        const auto content = QGuiApplication::clipboard()->mimeData()->data(QLatin1String("text/plain"));
+    else if (md->hasText()) {
+        const auto content = md->data(QLatin1String("text/plain"));
         importData(content);
     }
+
+    else if (md->hasFormat(QLatin1String("application/octet-stream"))) {
+        importData(md->data(QLatin1String("application/octet-stream")));
+    }
 }
 
 void ApplicationController::importFromUrl(const QUrl &url)
@@ -303,7 +314,7 @@ void ApplicationController::importLocalFile(const QUrl &url)
         qCWarning(Log) << "Failed to open" << f.fileName() << f.errorString();
         return;
     }
-    if (f.size() > 4000000) {
+    if (f.size() > 4000000 && !f.fileName().endsWith(QLatin1String(".itinerary"))) {
         qCWarning(Log) << "File too large, ignoring" << f.fileName() << f.size();
         return;
     }
@@ -382,7 +393,8 @@ void ApplicationController::checkCalendar()
 
 bool ApplicationController::hasClipboardContent() const
 {
-    return QGuiApplication::clipboard()->mimeData()->hasText() || QGuiApplication::clipboard()->mimeData()->hasUrls();
+    const auto md = QGuiApplication::clipboard()->mimeData();
+    return md->hasText() || md->hasUrls() || md->hasFormat(QLatin1String("application/octet-stream"));
 }
 
 
@@ -393,7 +405,7 @@ void ApplicationController::exportToFile(const QString &filePath)
         return;
     }
 
-    File f(filePath);
+    File f(QUrl(filePath).isLocalFile() ? QUrl(filePath).toLocalFile() : filePath);
     if (!f.open(File::Write)) {
         qCWarning(Log) << f.errorString();
         // TODO show error in UI
@@ -406,10 +418,34 @@ void ApplicationController::exportToFile(const QString &filePath)
     exporter.exportDocuments(m_docMgr);
     exporter.exportFavoriteLocations(m_favLocModel);
     exporter.exportTransfers(m_resMgr, m_transferMgr);
+    exporter.exportHealthCertificates(m_healthCertMgr);
     exporter.exportLiveData();
     exporter.exportSettings();
 }
 
+void ApplicationController::exportTripToGpx(const QString &tripGroupId, const QString &filePath)
+{
+    if (filePath.isEmpty()) {
+        return;
+    }
+
+    QFile f(QUrl(filePath).isLocalFile() ? QUrl(filePath).toLocalFile() : filePath);
+    if (!f.open(QFile::WriteOnly)) {
+        qCWarning(Log) << f.errorString() << f.fileName();
+        return;
+    }
+    GpxExport exporter(&f);
+
+    const auto tg = m_tripGroupMgr->tripGroup(tripGroupId);
+    const auto batches = tg.elements();
+    for (const auto &batchId : batches) {
+        const auto res = m_resMgr->reservation(batchId);
+        const auto transferBefore = m_transferMgr->transfer(batchId, Transfer::Before);
+        const auto transferAfter = m_transferMgr->transfer(batchId, Transfer::After);
+        exporter.writeReservation(res, m_liveDataMgr->journey(batchId), transferBefore, transferAfter);
+    }
+}
+
 void ApplicationController::importBundle(const QUrl &url)
 {
     KItinerary::File f(url.isLocalFile() ? url.toLocalFile() : url.toString());
@@ -445,6 +481,7 @@ void ApplicationController::importBundle(KItinerary::File *file)
     importer.importDocuments(m_docMgr);
     importer.importFavoriteLocations(m_favLocModel);
     importer.importTransfers(m_resMgr, m_transferMgr);
+    importer.importHealthCertificates(m_healthCertMgr);
     importer.importLiveData(m_liveDataMgr);
     importer.importSettings();
 
