@@ -4,6 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+#include "config-itinerary.h"
 #include "itinerary_version.h"
 #include "logging.h"
 
@@ -13,6 +14,7 @@
 #include "documentmanager.h"
 #include "documentsmodel.h"
 #include "favoritelocationmodel.h"
+#include "healthcertificatemanager.h"
 #include "livedatamanager.h"
 #include "localizer.h"
 #include "locationinformation.h"
@@ -52,6 +54,11 @@
 #include <KLocalizedContext>
 #include <KLocalizedString>
 
+#include <KAboutData>
+#if HAVE_KCRASH
+#include <KCrash>
+#endif
+
 #include <QQuickStyle>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
@@ -124,6 +131,7 @@ static WeatherForecastManager *s_weatherForecastManager = nullptr;
 static TripGroupInfoProvider s_tripGroupInfoProvider;
 static TripGroupProxyModel *s_tripGroupProxyModel = nullptr;
 static MapDownloadManager *s_mapDownloadManager = nullptr;
+static HealthCertificateManager *s_healthCertificateManager = nullptr;
 
 #define REGISTER_SINGLETON_INSTANCE(Class, Instance) \
     qmlRegisterSingletonType<Class>("org.kde.itinerary", 1, 0, #Class, [](QQmlEngine *engine, QJSEngine*) -> QObject* { \
@@ -155,6 +163,7 @@ void registerApplicationSingletons()
     REGISTER_SINGLETON_INSTANCE(WeatherForecastManager, s_weatherForecastManager)
     REGISTER_SINGLETON_INSTANCE(TripGroupProxyModel, s_tripGroupProxyModel)
     REGISTER_SINGLETON_INSTANCE(MapDownloadManager, s_mapDownloadManager)
+    REGISTER_SINGLETON_INSTANCE(HealthCertificateManager, s_healthCertificateManager)
 
     REGISTER_SINGLETON_GADGET_INSTANCE(TripGroupInfoProvider, s_tripGroupInfoProvider)
 
@@ -171,14 +180,18 @@ void registerApplicationSingletons()
 
 #undef REGISTER_SINGLETON_INSTANCE
 
-void handlePositionalArguments(ApplicationController *appController, const QStringList &args)
+void handlePositionalArguments(ApplicationController *appController, const QStringList &args, bool isTemporary)
 {
     for (const auto &file : args) {
         const auto localUrl = QUrl::fromLocalFile(file);
-        if (QFile::exists(localUrl.toLocalFile()))
+        if (QFile::exists(localUrl.toLocalFile())) {
             appController->importFromUrl(localUrl);
-        else
+            if (isTemporary) {
+                QFile::remove(localUrl.toLocalFile());
+            }
+        } else {
             appController->importFromUrl(QUrl::fromUserInput(file));
+        }
     }
 }
 
@@ -208,11 +221,21 @@ int main(int argc, char **argv)
     QGuiApplication::setApplicationDisplayName(i18n("KDE Itinerary"));
     QGuiApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("itinerary")));
 
+    auto aboutData = KAboutData::applicationData();
+    aboutData.setProductName("KDE Itinerary/general"); // Bugzilla product/component name
+    aboutData.setLicense(KAboutLicense::LGPL);
+    KAboutData::setApplicationData(aboutData);
+
     QCommandLineParser parser;
-    parser.addHelpOption();
-    parser.addVersionOption();
+    QCommandLineOption isTemporaryOpt(QStringLiteral("tempfile"), QStringLiteral("Input file is a temporary file and will be deleted after importing."));
+    parser.addOption(isTemporaryOpt);
+    aboutData.setupCommandLine(&parser);
     parser.addPositionalArgument(QStringLiteral("file"), i18n("PkPass or JSON-LD file to import."));
     parser.process(app);
+    aboutData.processCommandLine(&parser);
+#if HAVE_KCRASH
+    KCrash::initialize();
+#endif
 
 #ifndef Q_OS_ANDROID
     KDBusService service(KDBusService::Unique);
@@ -284,6 +307,9 @@ int main(int argc, char **argv)
     QObject::connect(s_settings, &Settings::preloadMapDataChanged, &mapDownloadMgr, &MapDownloadManager::setAutomaticDownloadEnabled);
     s_mapDownloadManager = &mapDownloadMgr;
 
+    HealthCertificateManager healthCertificateMgr;
+    s_healthCertificateManager = &healthCertificateMgr;
+
     ApplicationController appController;
     appController.setReservationManager(&resMgr);
     appController.setPkPassManager(&passMgr);
@@ -291,13 +317,15 @@ int main(int argc, char **argv)
     appController.setFavoriteLocationModel(&favLocModel);
     appController.setTransferManager(&transferManager);
     appController.setLiveDataManager(&liveDataMgr);
+    appController.setTripGroupManager(&tripGroupMgr);
+    appController.setHealthCertificateManager(&healthCertificateMgr);
 #ifndef Q_OS_ANDROID
-    QObject::connect(&service, &KDBusService::activateRequested, [&parser, &appController](const QStringList &args, const QString &workingDir) {
+    QObject::connect(&service, &KDBusService::activateRequested, [&](const QStringList &args, const QString &workingDir) {
         qCDebug(Log) << "remote activation" << args << workingDir;
         if (!args.isEmpty()) {
             QDir::setCurrent(workingDir);
             parser.parse(args);
-            handlePositionalArguments(&appController, parser.positionalArguments());
+            handlePositionalArguments(&appController, parser.positionalArguments(), parser.isSet(isTemporaryOpt));
         }
         if (!QGuiApplication::allWindows().isEmpty()) {
             QGuiApplication::allWindows().at(0)->requestActivate();
@@ -317,7 +345,7 @@ int main(int argc, char **argv)
     engine.rootContext()->setContextObject(l10nContext);
     engine.load(QStringLiteral("qrc:/main.qml"));
 
-    handlePositionalArguments(&appController, parser.positionalArguments());
+    handlePositionalArguments(&appController, parser.positionalArguments(), parser.isSet(isTemporaryOpt));
 #ifdef Q_OS_ANDROID
     using namespace KAndroidExtras;
     appController.importFromIntent(Activity::getIntent());
