@@ -9,6 +9,7 @@
 
 #include <utility>
 
+class QDateTime;
 class QString;
 class QVariant;
 
@@ -18,6 +19,12 @@ namespace ReservationHelper
     std::pair<QString, QString> lineNameAndNumber(const QVariant &res);
 
     bool equals(const QVariant &lhs, const QVariant &rhs);
+
+    /** Returns the arrival/departure time if available.
+     *  This returns an invalid time for unbound train tickets or bare flight boarding passes.
+     */
+    QDateTime departureTime(const QVariant &res);
+    QDateTime arrivalTime(const QVariant &res);
 }
 
 #endif // RESERVATIONHELPER_H
