@@ -8,13 +8,13 @@
 #include "logging.h"
 #include "favoritelocationmodel.h"
 #include "publictransport.h"
+#include "reservationhelper.h"
 #include "reservationmanager.h"
 #include "tripgroup.h"
 #include "tripgroupmanager.h"
 
 #include <KItinerary/LocationUtil>
 #include <KItinerary/Reservation>
-#include <KItinerary/SortUtil>
 
 #include <KPublicTransport/Journey>
 #include <KPublicTransport/JourneyReply>
@@ -99,7 +99,7 @@ void TransferManager::setJourneyForTransfer(Transfer transfer, const KPublicTran
     transfer.setJourney(journey);
     m_transfers[transfer.alignment()].insert(transfer.reservationId(), transfer);
     writeToFile(transfer);
-    emit transferChanged(transfer);
+    Q_EMIT transferChanged(transfer);
 }
 
 Transfer TransferManager::setFavoriteLocationForTransfer(Transfer transfer, const FavoriteLocation& favoriteLocation)
@@ -123,7 +123,7 @@ Transfer TransferManager::setFavoriteLocationForTransfer(Transfer transfer, cons
     transfer.setJourney({});
     m_transfers[transfer.alignment()].insert(transfer.reservationId(), transfer);
     writeToFile(transfer);
-    emit transferChanged(transfer);
+    Q_EMIT transferChanged(transfer);
 
     return transfer;
 }
@@ -199,11 +199,11 @@ void TransferManager::checkReservation(const QString &resId)
     const auto res = m_resMgr->reservation(resId);
 
     const auto now = currentDateTime();
-    if (SortUtil::endDateTime(res) < now) {
+    if (ReservationHelper::arrivalTime(res) < now) {
         return;
     }
     checkReservation(resId, res, Transfer::After);
-    if (SortUtil::startDateTime(res) < now) {
+    if (ReservationHelper::departureTime(res) < now) {
         return;
     }
     checkReservation(resId, res, Transfer::Before);
@@ -236,7 +236,7 @@ void TransferManager::checkReservation(const QString &resId, const QVariant &res
 
 TransferManager::CheckTransferResult TransferManager::checkTransferBefore(const QString &resId, const QVariant &res, Transfer &transfer) const
 {
-    transfer.setAnchorTime(SortUtil::startDateTime(res));
+    transfer.setAnchorTime(ReservationHelper::departureTime(res));
     const auto isLocationChange = LocationUtil::isLocationChange(res);
     QVariant toLoc;
     if (isLocationChange) {
@@ -292,7 +292,7 @@ TransferManager::CheckTransferResult TransferManager::checkTransferBefore(const
 
 TransferManager::CheckTransferResult TransferManager::checkTransferAfter(const QString &resId, const QVariant &res, Transfer &transfer) const
 {
-    transfer.setAnchorTime(SortUtil::endDateTime(res));
+    transfer.setAnchorTime(ReservationHelper::arrivalTime(res));
     const auto isLocationChange = LocationUtil::isLocationChange(res);
     QVariant fromLoc;
     if (isLocationChange) {
@@ -353,8 +353,8 @@ void TransferManager::reservationRemoved(const QString &resId)
     removeFile(resId, Transfer::Before);
     removeFile(resId, Transfer::After);
     // TODO updates to adjacent transfers?
-    emit transferRemoved(resId, Transfer::Before);
-    emit transferRemoved(resId, Transfer::After);
+    Q_EMIT transferRemoved(resId, Transfer::Before);
+    Q_EMIT transferRemoved(resId, Transfer::After);
 }
 
 void TransferManager::tripGroupChanged(const QString &tgId)
@@ -430,15 +430,15 @@ void TransferManager::addOrUpdateTransfer(Transfer &t)
         autoFillTransfer(t);
         m_transfers[t.alignment()].insert(t.reservationId(), t);
         writeToFile(t);
-        emit transferAdded(t);
+        Q_EMIT transferAdded(t);
     } else if (t.state() == Transfer::Discarded) {
         m_transfers[t.alignment()].insert(t.reservationId(), t);
         writeToFile(t);
-        emit transferRemoved(t.reservationId(), t.alignment());
+        Q_EMIT transferRemoved(t.reservationId(), t.alignment());
     } else { // update existing data
         m_transfers[t.alignment()].insert(t.reservationId(), t);
         writeToFile(t);
-        emit transferChanged(t);
+        Q_EMIT transferChanged(t);
     }
 }
 
@@ -449,7 +449,7 @@ void TransferManager::removeTransfer(const Transfer &t)
     }
     m_transfers[t.alignment()].remove(t.reservationId());
     removeFile(t.reservationId(), t.alignment());
-    emit transferRemoved(t.reservationId(), t.alignment());
+    Q_EMIT transferRemoved(t.reservationId(), t.alignment());
 }
 
 static QString transferBasePath()
@@ -495,7 +495,7 @@ void TransferManager::importTransfer(const Transfer &transfer)
     m_transfers[transfer.alignment()].insert(transfer.reservationId(), transfer);
     writeToFile(transfer);
 
-    update ? emit transferChanged(transfer) : emit transferAdded(transfer);
+    update ? Q_EMIT transferChanged(transfer) : Q_EMIT transferAdded(transfer);
 }
 
 KPublicTransport::JourneyRequest TransferManager::journeyRequestForTransfer(const Transfer &transfer) const
@@ -507,6 +507,8 @@ KPublicTransport::JourneyRequest TransferManager::journeyRequestForTransfer(cons
     req.setDateTime(transfer.journeyTime());
     req.setDateTimeMode(transfer.alignment() == Transfer::Before ? JourneyRequest::Arrival : JourneyRequest::Departure);
     req.setDownloadAssets(true);
+    req.setIncludeIntermediateStops(true);
+    req.setIncludePaths(true);
     return req;
 }
 
